@@ -5,4 +5,5 @@ utils::globalVariables(c(".", "context", "docname", "keyword",
                          "absdev", "p.value", "significant", "valueJitter",
                          "group", "featureID", "pattern", "token",
                          "contexts", "contexts_dem", "docid", "where",
-                         "tmp_by", "lower.ci", "upper.ci", "tokens_subset"))
+                         "tmp_by", "lower.ci", "upper.ci", "tokens_subset",
+                         "coefficient", "first_val", "sec_val", "val", "id", "i", "estimate", "std.error"))
